==> haskell-rank2classes-1.5.4-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.4
visibility:           public
id:                   rank2classes-1.5.4-2pEPl6VuQrX4Wg1x1B4t5p
key:                  rank2classes-1.5.4-2pEPl6VuQrX4Wg1x1B4t5p
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  f9127148f339cd2f2293fd47efe6035d
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.4-2pEPl6VuQrX4Wg1x1B4t5p
depends:
    base-4.17.2.1 data-functor-logistic-0.0-6uxa52DTkvVCDPpnW33WqX
    distributive-0.6.2.1-5yMbuFZA0eM91pdYKultUF
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rank2classes-1.5.4-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.4
visibility:           public
id:                   rank2classes-1.5.4-LBNa0PZ6W9CAxawFk3rEZY
key:                  rank2classes-1.5.4-LBNa0PZ6W9CAxawFk3rEZY
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  6e7b91aeb6a804ebda7d337198036e46
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.4-LBNa0PZ6W9CAxawFk3rEZY
depends:
    base-4.17.2.1 data-functor-logistic-0.0-Do8kxAJulVy9DqUYb5cHhp
    distributive-0.6.2.1-EgQHrl8pNDEGWugAZ9vv0V
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
